==> owncloud-10.0.7.tgz: owncloud/apps/files_external/l10n/pt_BR.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "A solicitação dos tokens de requesição falhou. Verifique se a sua chave de aplicativo e segurança estão corretos.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "A solicitação dos tokens de acesso falhou. Verifique se a sua chave de aplicativo e segurança estão corretos.",
    "Please provide a valid app key and secret." : "Por favor forneça uma chave e segurança válidos.",
    "Step 1 failed. Exception: %s" : "Passo 1 falhou. Exceção: %s",
    "Step 2 failed. Exception: %s" : "Passo 2 falhou. Exceção: %s",
    "External storage" : "Armazenamento Externo",
    "Dropbox App Configuration" : "Configuração do Aplicativo Dropbox",
    "Google Drive App Configuration" : "Configuração do Aplicativo Google Drive",
    "Personal" : "Pessoal",
    "System" : "Sistema",
    "Grant access" : "Permitir acesso",
    "Error configuring OAuth1" : "Erro configurando OAuth1",
    "Error configuring OAuth2" : "Erro configurando OAuth2",
    "Generate keys" : "Gerar chaves",
    "Error generating key pair" : "Erro ao gerar um par de chaves",
    "All users. Type to select user or group." : "Todos os usuários. Digite para selecionar usuário ou grupo.",
    "(group)" : "(grupo)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilidade com a codificação Mac NFD (lento)",
    "Admin defined" : "Definido pelo administrador",
    "Saved" : "Salvo",
    "Disabling external storage will unmount all storages for all users, are you sure ?" : "Desativar o armazenamento externo desmontará todos os armazenamentos para todos os usuários, você tem certeza?",
    "Disable external storage" : "Desativar armazenamento externo",
    "Empty response from the server" : "Resposta vazia a partir do servidor",
    "Couldn't access. Please logout and login to activate this mount point" : "Não foi possível acessar. Por favor, desconectar e conectar novamente para ativar este ponto de montagem",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Não foi possível obter as informações do servidor ownCloud: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Não foi possível obter a lista de pontos de montagem externos: {type}",
    "There was an error with message: " : "Houve um erro com a mensagem:",
    "External mount error" : "Erro de montagem externa",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Não foi possível obter a lista unidades de pontos de montagem da rede do Windows: resposta vazia a partir do servidor",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Alguns dos pontos de montagem externos configurados não estão conectados. Por favor clique na linha vermelha(s) para mais informações",
    "Please enter the credentials for the {mount} mount" : "Por favor, insira as credenciais para montar {mount}",
    "Username" : "Nome de Usuário",
    "Password" : "Senha",
    "Credentials saved" : "Credenciais salvas",
    "Credentials saving failed" : "A gravação das credenciais falhou",
    "Credentials required" : "Credenciais são exigidas",
    "Save" : "Salvar",
    "Storage with id \"%i\" not found" : "Armazenamento com id \"%i\" não encontrado",
    "Invalid backend or authentication mechanism class" : "Backend inválido ou classe de mecanismo de autenticação",
    "Invalid mount point" : "Ponto de montagem inválido",
    "Objectstore forbidden" : "Proibido armazenamento de objetos",
    "Invalid storage backend \"%s\"" : "Armazenamento backend inválido \"%s\"",
    "Not permitted to use backend \"%s\"" : "Não é permitido o uso de backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Não é permitido usar o mecanismo de autenticação \"%s\"",
    "Unsatisfied backend parameters" : "Parâmetros de back-end não-atendidos",
    "Unsatisfied authentication mechanism parameters" : "Parâmetros de mecanismos de autenticação não satisfeitos",
    "Insufficient data: %s" : "Dados insuficientes: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Armazenamento com ID \"%i\" não é editável pelo usuário",
    "Access key" : "Chave da acesso",
    "Secret key" : "Chave secreta",
    "OAuth1" : "OAuth1",
    "App key" : "Chave do Aplicativo",
    "App secret" : "Segredo da Aplicação",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID do Cliente",
    "Client secret" : "Segredo do cliente",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Nome do inquilino",
    "Identity endpoint URL" : "Identidade pontofinal URL",
    "Rackspace" : "Espaço em rack",
    "API key" : "Chave API",
    "RSA public key" : "Chave pública RSA",
    "Public key" : "Chave pública",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Cesta",
    "Hostname" : "Nome do Host",
    "Port" : "Porta",
    "Region" : "Região",
    "Enable SSL" : "Habilitar SSL",
    "Enable Path Style" : "Habilitar Estilo do Caminho",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subpasta remota",
    "Secure https://" : "https:// segura",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "Local" : "Local",
    "Location" : "Localização",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "Host",
    "Root" : "Raiz",
    "SFTP with secret key login" : "SFTP com chave secreta de login",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Compartilhar",
    "Domain" : "Domínio",
    "SMB / CIFS using OC login" : "SMB / CIFS usando OC login",
    "Username as share" : "Nome de usuário como compartilhado",
    "OpenStack Object Storage" : "Armazenamento de Objetos OpenStack",
    "Service name" : "Nome do serviço",
    "Request timeout (seconds)" : "Tempo esgotado requerido (segundos)",
    "<b>Note:</b> " : "<b>Nota:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> O suporte cURL do PHP não está habilitado ou instalado. Montagem de %s não é possível. Por favor, solicite ao seu administrador do sistema para instalá-lo.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> \"%s\" não está instalado. Montagem de %s não é possível. Por favor, solicite ao seu administrador do sistema para instalá-lo.",
    "No external storage configured" : "Nenhum armazendo externo foi configurado",
    "You can add external storages in the storage settings" : "Você pode adicionar armazenamento externo nas configurações de armazenamento",
    "Name" : "Nome",
    "Storage type" : "Tipo de armazenamento",
    "Scope" : "Escopo",
    "Enable encryption" : "Ativar criptografia",
    "Enable previews" : "Habilitar visualizações prévias",
    "Enable sharing" : "Habilitar compartilhamento",
    "Check for changes" : "Verifique se há alterações",
    "Never" : "Nunca",
    "Once every direct access" : "Uma vez a cada acesso direto",
    "External Storage" : "Armazenamento Externo",
    "Enable external storage" : "Ativar armazenamento externo",
    "External storage has been disabled by the administrator" : "O armazenamento externo foi desativado pelo administrador",
    "Folder name" : "Nome da pasta",
    "Authentication" : "Autenticação",
    "Configuration" : "Configuração",
    "Available for" : "Disponível para",
    "Add storage" : "Adicionar Armazenamento",
    "Advanced settings" : "Configurações avançadas",
    "Delete" : "Excluir",
    "Allow users to mount external storage" : "Permitir que usuários montem armazenamento externo",
    "Allow users to mount the following external storage" : "Permitir que usuários montem o seguinte armazenamento externo"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/files_external/l10n/pt_BR.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "A solicitação dos tokens de requesição falhou. Verifique se a sua chave de aplicativo e segurança estão corretos.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "A solicitação dos tokens de acesso falhou. Verifique se a sua chave de aplicativo e segurança estão corretos.",
    "Please provide a valid app key and secret." : "Por favor forneça uma chave e segurança válidos.",
    "Step 1 failed. Exception: %s" : "Passo 1 falhou. Exceção: %s",
    "Step 2 failed. Exception: %s" : "Passo 2 falhou. Exceção: %s",
    "External storage" : "Armazenamento Externo",
    "Dropbox App Configuration" : "Configuração do Aplicativo Dropbox",
    "Google Drive App Configuration" : "Configuração do Aplicativo Google Drive",
    "Personal" : "Pessoal",
    "System" : "Sistema",
    "Grant access" : "Permitir acesso",
    "Error configuring OAuth1" : "Erro configurando OAuth1",
    "Error configuring OAuth2" : "Erro configurando OAuth2",
    "Generate keys" : "Gerar chaves",
    "Error generating key pair" : "Erro ao gerar um par de chaves",
    "All users. Type to select user or group." : "Todos os usuários. Digite para selecionar usuário ou grupo.",
    "(group)" : "(grupo)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilidade com a codificação Mac NFD (lento)",
    "Admin defined" : "Definido pelo administrador",
    "Saved" : "Salvo",
    "Disabling external storage will unmount all storages for all users, are you sure ?" : "Desativar o armazenamento externo desmontará todos os armazenamentos para todos os usuários, você tem certeza?",
    "Disable external storage" : "Desativar armazenamento externo",
    "Empty response from the server" : "Resposta vazia a partir do servidor",
    "Couldn't access. Please logout and login to activate this mount point" : "Não foi possível acessar. Por favor, desconectar e conectar novamente para ativar este ponto de montagem",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Não foi possível obter as informações do servidor ownCloud: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Não foi possível obter a lista de pontos de montagem externos: {type}",
    "There was an error with message: " : "Houve um erro com a mensagem:",
    "External mount error" : "Erro de montagem externa",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Não foi possível obter a lista unidades de pontos de montagem da rede do Windows: resposta vazia a partir do servidor",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Alguns dos pontos de montagem externos configurados não estão conectados. Por favor clique na linha vermelha(s) para mais informações",
    "Please enter the credentials for the {mount} mount" : "Por favor, insira as credenciais para montar {mount}",
    "Username" : "Nome de Usuário",
    "Password" : "Senha",
    "Credentials saved" : "Credenciais salvas",
    "Credentials saving failed" : "A gravação das credenciais falhou",
    "Credentials required" : "Credenciais são exigidas",
    "Save" : "Salvar",
    "Storage with id \"%i\" not found" : "Armazenamento com id \"%i\" não encontrado",
    "Invalid backend or authentication mechanism class" : "Backend inválido ou classe de mecanismo de autenticação",
    "Invalid mount point" : "Ponto de montagem inválido",
    "Objectstore forbidden" : "Proibido armazenamento de objetos",
    "Invalid storage backend \"%s\"" : "Armazenamento backend inválido \"%s\"",
    "Not permitted to use backend \"%s\"" : "Não é permitido o uso de backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Não é permitido usar o mecanismo de autenticação \"%s\"",
    "Unsatisfied backend parameters" : "Parâmetros de back-end não-atendidos",
    "Unsatisfied authentication mechanism parameters" : "Parâmetros de mecanismos de autenticação não satisfeitos",
    "Insufficient data: %s" : "Dados insuficientes: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Armazenamento com ID \"%i\" não é editável pelo usuário",
    "Access key" : "Chave da acesso",
    "Secret key" : "Chave secreta",
    "OAuth1" : "OAuth1",
    "App key" : "Chave do Aplicativo",
    "App secret" : "Segredo da Aplicação",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID do Cliente",
    "Client secret" : "Segredo do cliente",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Nome do inquilino",
    "Identity endpoint URL" : "Identidade pontofinal URL",
    "Rackspace" : "Espaço em rack",
    "API key" : "Chave API",
    "RSA public key" : "Chave pública RSA",
    "Public key" : "Chave pública",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Cesta",
    "Hostname" : "Nome do Host",
    "Port" : "Porta",
    "Region" : "Região",
    "Enable SSL" : "Habilitar SSL",
    "Enable Path Style" : "Habilitar Estilo do Caminho",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subpasta remota",
    "Secure https://" : "https:// segura",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "Local" : "Local",
    "Location" : "Localização",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "Host",
    "Root" : "Raiz",
    "SFTP with secret key login" : "SFTP com chave secreta de login",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Compartilhar",
    "Domain" : "Domínio",
    "SMB / CIFS using OC login" : "SMB / CIFS usando OC login",
    "Username as share" : "Nome de usuário como compartilhado",
    "OpenStack Object Storage" : "Armazenamento de Objetos OpenStack",
    "Service name" : "Nome do serviço",
    "Request timeout (seconds)" : "Tempo esgotado requerido (segundos)",
    "<b>Note:</b> " : "<b>Nota:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> O suporte cURL do PHP não está habilitado ou instalado. Montagem de %s não é possível. Por favor, solicite ao seu administrador do sistema para instalá-lo.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> \"%s\" não está instalado. Montagem de %s não é possível. Por favor, solicite ao seu administrador do sistema para instalá-lo.",
    "No external storage configured" : "Nenhum armazendo externo foi configurado",
    "You can add external storages in the storage settings" : "Você pode adicionar armazenamento externo nas configurações de armazenamento",
    "Name" : "Nome",
    "Storage type" : "Tipo de armazenamento",
    "Scope" : "Escopo",
    "Enable encryption" : "Ativar criptografia",
    "Enable previews" : "Habilitar visualizações prévias",
    "Enable sharing" : "Habilitar compartilhamento",
    "Check for changes" : "Verifique se há alterações",
    "Never" : "Nunca",
    "Once every direct access" : "Uma vez a cada acesso direto",
    "External Storage" : "Armazenamento Externo",
    "Enable external storage" : "Ativar armazenamento externo",
    "External storage has been disabled by the administrator" : "O armazenamento externo foi desativado pelo administrador",
    "Folder name" : "Nome da pasta",
    "Authentication" : "Autenticação",
    "Configuration" : "Configuração",
    "Available for" : "Disponível para",
    "Add storage" : "Adicionar Armazenamento",
    "Advanced settings" : "Configurações avançadas",
    "Delete" : "Excluir",
    "Allow users to mount external storage" : "Permitir que usuários montem armazenamento externo",
    "Allow users to mount the following external storage" : "Permitir que usuários montem o seguinte armazenamento externo",
    "No URL provided by backend " : "Nenhum URL fornecido pelo backend",
    "Please make sure that the app that provides this backend is installed and enabled" : "Certifique-se de que o aplicativo que fornece este backend está instalado e habilitado",
    "Allow sharing on user-mounted external storages" : "Permitir o compartilhamento em armazenamentos externos montados pelo usuário",
    "Error getting OAuth2 URL for " : "Erro ao obter o URL OAuth2 para"
},
"nplurals=2; plural=(n > 1);");
